@@ -6,15 +6,13 @@ from os import path
 from typing import List, Optional
 from zipfile import ZIP_DEFLATED, ZipFile
 
-import boto3
-from aws_assume_role_lib import assume_role
 from metaphor.models.crawler_run_metadata import CrawlerRunMetadata
 from pydantic.dataclasses import dataclass
 from serde import deserialize
 
 from .logger import LOG_FILE, get_logger
-from .s3 import write_file
 from .sink import Sink
+from .storage import BaseStorage, LocalStorage, S3Storage
 
 logger = get_logger(__name__)
 
@@ -44,25 +42,29 @@ class FileSink(Sink):
         self.bach_size = config.bach_size
         self.write_logs = config.write_logs
 
-        self.s3_session = None
-        if config.assume_role_arn is not None:
-            self.s3_session = assume_role(boto3.Session(), config.assume_role_arn)
-            logger.info(
-                f"Assumed role: {self.s3_session.client('sts').get_caller_identity()}"
-            )
+        if config.directory.startswith("s3://"):
+            self._storage: BaseStorage = S3Storage(config.assume_role_arn)
+        else:
+            self._storage = LocalStorage()
 
     def _sink(self, messages: List[dict]) -> bool:
         """Write records to file with auto-splitting"""
 
+        # purge existing MCE json files
+        existing = self._storage.list_files(self.path, ".json")
+        self._storage.delete_files(existing)
+        logger.info(f"deleted {len(existing)} MCE files")
+
+        # split MCE into batches and write to files
         bach_size = self.bach_size
         parts = math.ceil(len(messages) / bach_size)
 
         for i in range(0, parts):
-            write_file(
-                f"{self.path}/{i+1}-of-{parts}.json",
+            self._storage.write_file(
+                f"{self.path}/{i + 1}-of-{parts}.json",
                 json.dumps(messages[i * bach_size : (i + 1) * bach_size]),
-                s3_session=self.s3_session,
             )
+        logger.info(f"written {parts} MCE files")
 
         return True
 
@@ -79,9 +81,7 @@ class FileSink(Sink):
             file.write(LOG_FILE, arcname=arcname)
 
         with open(zip_file, "rb") as file:
-            write_file(
-                f"{self.path}/log.zip", file.read(), True, s3_session=self.s3_session
-            )
+            self._storage.write_file(f"{self.path}/log.zip", file.read(), True)
 
     def sink_metadata(self, metadata: CrawlerRunMetadata):
         if not self.write_logs:
@@ -90,6 +90,4 @@ class FileSink(Sink):
 
         content = json.dumps(metadata.to_dict()).encode()
 
-        write_file(
-            f"{self.path}/run.metadata", content, True, s3_session=self.s3_session
-        )
+        self._storage.write_file(f"{self.path}/run.metadata", content, True)
